@@ -1,6 +1,6 @@
 -- |
 -- Module      : Database.Relational.Table
--- Copyright   : 2013-2017 Kei Hibino
+-- Copyright   : 2013-2019 Kei Hibino
 -- License     : BSD3
 --
 -- Maintainer  : ex8k.hibino@gmail.com
@@ -24,7 +24,7 @@ import Database.Record.Persistable
   (PersistableWidth, PersistableRecordWidth, unsafePersistableRecordWidth)
 
 import Database.Relational.Internal.UntypedTable (Untyped (Untyped), name', width', columns', (!))
-import Database.Relational.Internal.String (StringSQL, stringSQL, )
+import Database.Relational.Internal.String (StringSQL, stringSQL, showStringSQL)
 import Database.Relational.SqlSyntax (SubQuery)
 import qualified Database.Relational.SqlSyntax as Syntax
 
@@ -32,6 +32,12 @@ import qualified Database.Relational.SqlSyntax as Syntax
 -- | Phantom typed table type
 newtype Table r = Table Untyped
 
+instance Show (Table r) where
+  show t =
+    unwords
+    ["Table",  show $ name t,
+     show . map showStringSQL $ columns t]
+
 -- | Untype table.
 untype :: Table t -> Untyped
 untype (Table u) = u
